module.exports = defineTest({
	description: 'retains side-effect-free code in try-statement-blocks'
});
